import asyncio
import os
import time
from mitmproxy import options
from mitmproxy.tools import dump

sleep_time = float(os.getenv('DELAY_IN_SECONDS', 0.015))
hosts_to_intercept = set([
    host.strip()
    .replace("https://", "")
    .replace("http://", "")
    .replace("www.","")
    for host in os.getenv('HOSTS_TO_INTERCEPT', "").split(',')
])
term_log=bool(os.getenv('TERM_LOG', "False"))
with_dumper = bool(os.getenv('WITH_DUMPER', "False"))


class RequestLogger:
    def request(self, flow):
        host = flow.request.host.replace("www.","") if flow.request.host else None
        if host in hosts_to_intercept:
            time.sleep(sleep_time)


async def start_proxy(host, port):
    opts = options.Options(listen_host=host, listen_port=port)

    master = dump.DumpMaster(
        opts,
        with_termlog=term_log,
        with_dumper=with_dumper,
    )
    master.addons.add(RequestLogger())
    await master.run()
    return master


def start_service():
    port = int(os.getenv('SERVER_PORT') or 9001)
    print(f"Intercepting below hosts with delay of {sleep_time} seconds")
    for host in hosts_to_intercept:
        print(host)
    print(f"Starting proxy server on port {port}...")
    asyncio.run(start_proxy("0.0.0.0", port))


if __name__ == '__main__':
    start_service()
